@@ -15,12 +15,13 @@ def load_json_or_dict(json_or_dict):
 
 
 class JsonMAJ:
-    def __init__(self, json_path, update_values={}):
+    def __init__(self, json_path, update_values={}, indent=4):
         self.json_path = json_path
         self.json_data = load_json_or_dict(self.json_path)
         self.update_values = load_json_or_dict(update_values)
+        self.indent = indent
 
-    def update(self):
+    def update(self, values=None):
         try:
             with open(self.json_path, 'r') as infile:
                 try:
@@ -30,14 +31,20 @@ class JsonMAJ:
         except FileNotFoundError:
             pass
 
-        self.json_data.update(self.update_values)
+        if values:
+            self.json_data.update(values)
+        else:
+            self.json_data.update(self.update_values)
 
         with open(self.json_path, 'w') as outfile:
-            json.dump(self.json_data, outfile)
+            json.dump(self.json_data, outfile, indent=self.indent)
 
     def remove(self, *keys):
         for key in keys:
             self.json_data.pop(key, None)
 
         with open(self.json_path, 'w') as outfile:
-            json.dump(self.json_data, outfile)
+            json.dump(self.json_data, outfile, indent=self.indent)
+
+    def get(self, item):
+        return self.json_data.get(item, None)
\ No newline at end of file
